]> sigrok.org Git - pulseview.git/blobdiff - main.cpp
Use C++ style comments in main.cpp
[pulseview.git] / main.cpp
index 3d6b86e3651b3004c95d87c8d7d0c77c41024613..febe729c4bc97d0ea25e095ada555525c8f062b2 100644 (file)
--- a/main.cpp
+++ b/main.cpp
@@ -1,5 +1,5 @@
 /*
* This file is part of the sigrok project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>
  *
@@ -26,33 +26,36 @@ extern "C" {
 
 #include <QtGui/QApplication>
 #include <QDebug>
-#include "mainwindow.h"
+
+#include "pv/mainwindow.h"
+
+#include "config.h"
 
 int main(int argc, char *argv[])
 {
        QApplication a(argc, argv);
 
-       /* Set some application metadata. */
-       QApplication::setApplicationVersion(APP_VERSION);
-       QApplication::setApplicationName("sigrok-qt");
+       // Set some application metadata
+       QApplication::setApplicationVersion(PV_VERSION_STRING);
+       QApplication::setApplicationName("PulseView");
        QApplication::setOrganizationDomain("http://www.sigrok.org");
 
-       /* Initialise libsigrok */
+       // Initialise libsigrok
        if (sr_init() != SR_OK) {
                qDebug() << "ERROR: libsigrok init failed.";
                return 1;
        }
 
-       /* Initialise libsigrokdecode */
+       // Initialise libsigrokdecode
        if (srd_init(NULL) != SRD_OK) {
                qDebug() << "ERROR: libsigrokdecode init failed.";
                return 1;
        }
 
-       /* Load the protocol decoders */
+       // Load the protocol decoders
        srd_decoder_load_all();
 
-       /* Initialize all libsigrok drivers. */
+       // Initialize all libsigrok drivers
        sr_dev_driver **const drivers = sr_driver_list();
        for (sr_dev_driver **driver = drivers; *driver; driver++) {
                if (sr_driver_init(*driver) != SR_OK) {
@@ -62,14 +65,14 @@ int main(int argc, char *argv[])
                }
        }
 
-       /* Initialise the main window */
-       MainWindow w;
+       // Initialise the main window
+       pv::MainWindow w;
        w.show();
 
-       /* Run the application */
+       // Run the application
        const int ret = a.exec();
 
-       /* Destroy libsigrokdecode and libsigrok */
+       // Destroy libsigrokdecode and libsigrok
        srd_exit();
        sr_exit();
@@ -1,5 +1,5 @@
 /*
- * This file is part of the sigrok project.
+ * This file is part of the PulseView project.
  *
  * Copyright (C) 2012 Joel Holdsworth <joel@airwebreathe.org.uk>